==> mono-uia_1.0.orig.tar.gz: mono-uia-1.0/UIAutomationTypes/System.Windows.Automation/StructureChangedEventArgs.cs <==
// Permission is hereby granted, free of charge, to any person obtaining 
// a copy of this software and associated documentation files (the 
// "Software"), to deal in the Software without restriction, including 
// without limitation the rights to use, copy, modify, merge, publish, 
// distribute, sublicense, and/or sell copies of the Software, and to 
// permit persons to whom the Software is furnished to do so, subject to 
// the following conditions: 
//  
// The above copyright notice and this permission notice shall be 
// included in all copies or substantial portions of the Software. 
//  
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE 
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION 
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
// 
// Copyright (c) 2008 Novell, Inc. (http://www.novell.com) 
// 
// Authors: 
//      Calvin Gaisford <calvinrg@gmail.com>
// 

using System;

namespace System.Windows.Automation
{
	public sealed class StructureChangedEventArgs : AutomationEventArgs
	{
		private StructureChangeType structureChangeType;
		private int[] runtimeId;
		
		public StructureChangeType StructureChangeType { 
			get {
				return structureChangeType;
			}
		}

		public StructureChangedEventArgs (StructureChangeType structureChangeType, int[] runtimeId) :
			base (AutomationEvent.LookupById(0)) // TODO: Is 0 correct?
		{
			this.structureChangeType = structureChangeType;
			this.runtimeId = runtimeId;
		}

		public int[] GetRuntimeId ()
		{
			return runtimeId;
		}
	}
}

==> mono-uia_2.1.orig.tar.gz: mono-uia-2.1/UIAutomationTypes/System.Windows.Automation/StructureChangedEventArgs.cs <==
// Permission is hereby granted, free of charge, to any person obtaining 
// a copy of this software and associated documentation files (the 
// "Software"), to deal in the Software without restriction, including 
// without limitation the rights to use, copy, modify, merge, publish, 
// distribute, sublicense, and/or sell copies of the Software, and to 
// permit persons to whom the Software is furnished to do so, subject to 
// the following conditions: 
//  
// The above copyright notice and this permission notice shall be 
// included in all copies or substantial portions of the Software. 
//  
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND 
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE 
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION 
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
// 
// Copyright (c) 2008 Novell, Inc. (http://www.novell.com) 
// 
// Authors: 
//      Calvin Gaisford <calvinrg@gmail.com>
// 

using System;

namespace System.Windows.Automation
{
	public sealed class StructureChangedEventArgs : AutomationEventArgs
	{
		private StructureChangeType structureChangeType;
		private int[] runtimeId;
		
		public StructureChangeType StructureChangeType { 
			get {
				return structureChangeType;
			}
		}

		public StructureChangedEventArgs (StructureChangeType structureChangeType, int[] runtimeId) :
			base (AutomationElementIdentifiers.StructureChangedEvent)
		{
			this.structureChangeType = structureChangeType;
			this.runtimeId = runtimeId;
		}

		public int[] GetRuntimeId ()
		{
			return runtimeId;
		}
	}
}
